@@ -1,26 +1,5 @@
-#
+# SPDX-License-Identifier: Apache-2.0
 # Copyright Contributors to the OpenTimelineIO project
-#
-# Licensed under the Apache License, Version 2.0 (the "Apache License")
-# with the following modification; you may not use this file except in
-# compliance with the Apache License and the following modification to it:
-# Section 6. Trademarks. is deleted and replaced with:
-#
-# 6. Trademarks. This License does not grant permission to use the trade
-#    names, trademarks, service marks, or product names of the Licensor
-#    and its affiliates, except as required to comply with Section 4(c) of
-#    the License and to reproduce the content of the NOTICE file.
-#
-# You may obtain a copy of the Apache License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the Apache License with the above modification is
-# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied. See the Apache License for the specific
-# language governing permissions and limitations under the Apache License.
-#
 
 """RvSession Adapter harness"""
 
@@ -89,11 +68,13 @@ def write_to_file(input_otio, filepath):
     # rest of the code should catch the error case and print the (presumably)
     # helpful message from the subprocess.
     try:
-        proc.stdin.write(json.dumps(simplified_data))
+        proc.stdin.write(json.dumps(simplified_data).encode())
     except IOError:
         pass
 
     out, err = proc.communicate()
+    out = out.decode()
+    err = err.decode()
 
     if out.strip():
         print("stdout: {}".format(out))
